#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.vaccine as vacc
import emod_api.campaign as camp



class Testvacc(TestIntervention):
    """
    Test SimpleVaccine intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(vacc.Vaccine, "SimpleVaccine", "camp_vacc.json", is_multi=True)

    def test_all(self, intervention_class_name='SimpleVaccine'):
        camp.set_schema( self.schema )
        trigger_treatment_list = ['infected']
        initial_efficacy = 0.9
        vaccine_take = 0
        vtype = 'AcquisitionBlocking'
        box_duration = 366
        immune_decay = 3651
        start_day = 2
        duration = 70
        property_restrictions_list = ["Risk: HIGH"]
        nodeIDs = []
        black_period = 11
        black_trigger = 'Blackout'
        event_name = 'Vaccine'

        event = vacc.Vaccine(camp, trigger_treatment_list, initial_efficacy, vaccine_take, vtype, box_duration,
                             immune_decay, start_day, duration, property_restrictions_list, nodeIDs, black_period,
                             black_trigger, event_name)

        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_vacc.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)

        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        intervention = ic["Actual_IndividualIntervention_Config"]
        intervention_list = intervention["Intervention_List"]
        found_it = False
        for listed_intervention in intervention_list:
            if listed_intervention["class"] == intervention_class_name:
                found_it = True
                self.assertEqual(listed_intervention["Waning_Config"]['Initial_Effect'],
                                 initial_efficacy)
                self.assertEqual(listed_intervention["Vaccine_Take"], vaccine_take)
                self.assertEqual(listed_intervention["Vaccine_Type"], vtype)
                self.assertEqual(listed_intervention["Waning_Config"]['Box_Duration'],
                                 box_duration)
                self.assertEqual(listed_intervention["Waning_Config"]['Decay_Time_Constant'],
                                 immune_decay)

        self.assertTrue(found_it, msg=f"Expected to find {intervention_class_name} in list,"
                                      f" got {str(intervention_list)}")

        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(ic["Duration"], duration)
        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in
                                                           property_restrictions_list])
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)

    def test_new_intervention_as_file(self, intervention_class_name='SimpleVaccine'):
        camp_filename = os.path.join(self.output, 'camp_vacc_as_file.json')
        super().new_intervention_as_file_test(vacc, camp_filename, intervention_class_name, is_multi=True)


if __name__ == '__main__':
    unittest.main()

